OC.L10N.register(
    "spreed",
    {
    "Validate SSL certificate" : "Vahvista SSL-varmenne",
    "Delete server" : "Poista palvelin",
    "Add new server" : "Lisää uusi palvelin",
    "Saved" : "Tallennettu",
    "You deleted all STUN servers. As it is almost always needed, a default STUN server was added." : "Poistit kaikki STUN-palvelimet. Koska STUN-palvelinta tarvitaan lähes aina, lisäsimme oletuksena käytettävän STUN-palvelimen.",
    "STUN server URL" : "STUN-palvelimen osoite",
    "TURN server URL" : "TURN-palvelimen osoite",
    "Shared secret" : "Jaettu salaisuus",
    "TURN server shared secret" : "TURN-palvelimen jaettu salausavain",
    "UDP and TCP" : "UDP ja TCP",
    "UDP only" : "Vain UDP",
    "TCP only" : "Vain TCP",
    "TURN server protocols" : "TURN-palvelimen protokollat",
    "New public conversation" : "Uusi julkinen keskustelu",
    "New group conversation" : "Uusi ryhmäkeskustelu",
    "{name} (public)" : "{name} (julkinen)",
    "New conversation …" : "Uusi keskustelu…",
    "Participants" : "Osallistujat",
    "Chat" : "Keskustelu",
    "Talk" : "Puhe",
    "Exit fullscreen (f)" : "Poistu koko näytön tilasta (f)",
    "Fullscreen (f)" : "Koko näytön tila (f)",
    "Set your name in the chat window so other participants can identify you better." : "Aseta nimesi keskusteluikkunassa, jotta muut osalliset tunnistavat sinut.",
    "Copy" : "Kopioi",
    "Copied!" : "Kopioitu!",
    "Not supported!" : "Ei tuettu!",
    "Press ⌘-C to copy." : "Paina ⌘-C kopioidaksesi.",
    "Press Ctrl-C to copy." : "Paina Ctrl-C kopioidaksesi.",
    "Share" : "Jaa",
    "Request password" : "Pyydä salasana",
    "Error requesting the password." : "Virhe pyytäessä salasanaa.",
    "Please enter the password for this call" : "Anna salasana tälle puhelulle",
    "Password required" : "Salasana vaaditaan",
    "Password" : "Salasana",
    "Cancel" : "Peru",
    "Submit" : "Lähetä",
    "Leave call" : "Poistu puhelusta",
    "Join call" : "Liity puheluun",
    "Start call" : "Aloita puhelu",
    "Share link" : "Jaa linkki",
    "Change password" : "Vaihda salasana",
    "Set password" : "Aseta salasana",
    "Name" : "Nimi",
    "Conversation name" : "Keskustelun nimi",
    "Rename" : "Nimeä uudelleen",
    "Copy link" : "Kopioi linkki",
    "Conversation with {name}" : "Keskustelu henkilön {name} kanssa",
    "Error occurred while setting password" : "Virhe salasanaa asettaessa",
    "Link copied!" : "Linkki kopioitu!",
    "You" : "Sinä",
    "No messages yet, start the conversation!" : "Ei vielä viestejä, aloita keskustelu!",
    "New message …" : "Uusi viesti …",
    "Send" : "Lähetä",
    "Guest" : "Vieras",
    "[Unknown user name]" : "[Tuntematon käyttäjänimi]",
    "Today" : "Tänään",
    "Yesterday" : "Eilen",
    "The message you are trying to send is too long" : "Viesti, jonka yrität lähettää, on liian pitkä",
    "Error occurred while sending message" : "Viestiä lähettäessä tapahtui virhe",
    "File to share" : "Jaettava tiedosto",
    "Error while sharing" : "Virhe jaettaessa",
    "Edit" : "Muokkaa",
    "Join a conversation or start a new one" : "Liity keskusteluun tai aloita uusi",
    "No other people in this call" : "Ei muita henkilöitä tässä puhelussa",
    "Waiting for {participantName} to join the call …" : "Odotetaan henkilön {participantName} liittymistä puheluun...",
    "Waiting for others to join the call …" : "Odotetaan muiden liittymistä puheluun...",
    "You can invite others in the participant tab of the sidebar" : "Voit kutsua muita sivupalkissa olevan Osallistujat-välilehden kautta",
    "Share this link to invite others!" : "Jaa tämä linkki kutsuaksesi muita!",
    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Voit kutsua muita sivupalkissa olevan Osallistujat-välilehden kautta tai jakamalla tämän linkin!",
    "WebRTC is not supported in your browser :-/" : "WebRTC ei ole tuettuna selaimessasi :-/",
    "Please use a different browser like Firefox or Chrome" : "Käytä jotain toista selainta, kuten Firefoxia tai Chromea",
    "Waiting for camera and microphone permissions" : "Odotetaan käyttöoikeuden myöntämistä kameralle ja mikrofonille",
    "Please, give your browser access to use your camera and microphone in order to use this app." : "Anna selaimellesi oikeus käyttää kameraa ja mikrofonia käyttääksesi tätä sovellusta.",
    "This conversation has ended" : "Tämä keskustelu on päättynyt",
    "Disable video" : "Poista video käytöstä",
    "Share screen" : "Jaa näyttö",
    "Show your screen" : "Näytä oma näyttösi",
    "Stop screensharing" : "Lopeta näytön jakaminen",
    "Unmute audio (m)" : "Palauta äänet (m)",
    "Mute audio (m)" : "Mykistä äänet (m)",
    "No audio" : "Ei ääntä",
    "Enable video (v)" : "Ota video käyttöön (v)",
    "Disable video (v)" : "Poista video käytöstä (v)",
    "No Camera" : "Ei kameraa",
    "Screensharing is not supported by your browser." : "Selaimesi ei tue näytönjakoa.",
    "Screensharing requires the page to be loaded through HTTPS." : "Näytön jakaminen vaatii sivun lataamista HTTPS-protokollalla.",
    "Screensharing options" : "Näytönjakamisen valinnat",
    "Sharing your screen only works with Firefox version 52 or newer." : "Näytön jakaminen toimii vain Firefox-selaimen versiolla 52 tai sitä uudemmilla.",
    "Screensharing extension is required to share your screen." : "Liitännäinen vaaditaan näytön jakamiseen.",
    "Please use a different browser like Firefox or Chrome to share your screen." : "Käytä näytön jakamiseen jotain toista selainta, kuten Firefoxia tai Chromea.",
    "An error occurred while starting screensharing." : "Virhe aloitettaessa näytön jakamista.",
    "Enable screensharing" : "Ota käyttöön näytönjakaminen",
    "moderator" : "moderaattori",
    "Demote from moderator" : "Alenna moderaattorista",
    "Promote to moderator" : "Ylennä moderaattoriksi",
    "Remove participant" : "Poista osallistuja",
    "Error while removing user from room" : "Virhe poistaessa käyttäjää huoneesta",
    "Add participant …" : "Lisää osallistuja…",
    "Favorited" : "Lisätty suosikkeihin",
    "Remove from favorites" : "Poista suosikeista",
    "Add to favorites" : "Lisää suosikkeihin",
    "Always notify" : "Ilmoita aina",
    "Notify on @-mention" : "Ilmoita @-maininnoista",
    "Never notify" : "Älä ilmoita koskaan",
    "Leave conversation" : "Poistu keskustelusta",
    "Delete conversation" : "Poista keskustelu",
    "Close" : "Sulje",
    "Show screen" : "Näytä näyttö",
    "Enable video" : "Käytä videota",
    "Access to microphone & camera is only possible with HTTPS" : "Kameran ja mikrofonin käyttäminen on mahdollista vain käytettäessä HTTPS-protokollaa",
    "Please move your setup to HTTPS" : "Siirrä asetuksesi HTTPS:n taakse",
    "Access to microphone & camera was denied" : "Yhteys mikrofoniin ja kameraan estettiin",
    "WebRTC is not supported in your browser" : "WebRTC ei ole tuettuna selaimessasi",
    "Error while accessing microphone & camera" : "Virhe yhdistettäessä mikrofoniin ja kameraan",
    "{participantName}'s screen" : "Henkilön {participantName} näyttö",
    "Guest's screen" : "Vieraan näyttö",
    "Your screen" : "Sinun näyttösi",
    "a conversation" : "keskustelu",
    "(Duration %s)" : "(Kesto %s)",
    "You attended a call with {user1}" : "Osallistuit puheluun käyttäjän {user1} kanssa",
    "_%n guest_::_%n guests_" : ["%n vieras","%n vierasta"],
    "You attended a call with {user1} and {user2}" : "Osallistuit puheluun käyttäjien {user1} ja {user2} kanssa",
    "You attended a call with {user1}, {user2} and {user3}" : "Osallistuit puheluun käyttäjien {user1}, {user2} ja {user3} kanssa",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "Osallistuit puheluun käyttäjien {user1}, {user2}, {user3} ja {user4} kanssa",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Osallistuit puheluun käyttäjien {user1}, {user2}, {user3}, {user4} ja {user5} kanssa",
    "_%n other_::_%n others_" : ["%n muu","%n muuta"],
    "{actor} invited you to {call}" : "{actor} kutsui sinut puheluun {call}",
    "{actor} created the conversation" : "{actor} loi keskustelun",
    "You created the conversation" : "Sinä loit keskustelun",
    "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "{actor} muutti keskustelun \"%1$s\" uudeksi nimeksi \"%2$s\"",
    "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "Sinä muutit keskustelun \"%1$s\" uudeksi nimeksi \"%2$s\"",
    "{actor} started a call" : "{actor} aloitti puhelun",
    "You started a call" : "Sinä aloitit puhelun",
    "{actor} joined the call" : "{actor} liittyi puheluun",
    "You joined the call" : "Sinä liityit puheluun",
    "{actor} left the call" : "{actor} poistui puhelusta",
    "You left the call" : "Sinä poistuit puhelusta",
    "{actor} allowed guests" : "{actor} salli vieraat",
    "You allowed guests" : "Sinä sallit vieraat",
    "{actor} disallowed guests" : "{actor} esti vieraat",
    "You disallowed guests" : "Sinä estit vieraat",
    "{actor} set a password" : "{actor} asetti salasanan",
    "You set a password" : "Sinä asetit salasanan",
    "{actor} removed the password" : "{actor} poisti salasanan",
    "You removed the password" : "Sinä poistit salasanan",
    "{actor} added {user}" : "{actor} lisäsi käyttäjän {user}",
    "You added {user}" : "Sinä lisäsit käyttäjän {user}",
    "{actor} added you" : "{actor} lisäsi sinut",
    "{actor} left the conversation" : "{actor} poistui keskustelusta",
    "{actor} removed {user}" : "{actor} poisti käyttäjän {user}",
    "You removed {user}" : "Sinä poistit käyttäjän {user}",
    "{actor} removed you" : "{actor} poisti sinut",
    "{actor} promoted {user} to moderator" : "{actor} nosti käyttäjän {user} moderaattoriksi",
    "You promoted {user} to moderator" : "Sinä nostit käyttäjän {user} moderaattoriksi",
    "{actor} promoted you to moderator" : "{actor} nosti sinut moderaattoriksi",
    "{actor} demoted {user} from moderator" : "{actor} poisti moderaattorin oikeudet käyttäjältä {user}",
    "You demoted {user} from moderator" : "Sinä poistit moderaattorin oikeudet käyttäjältä {user}",
    "{actor} demoted you from moderator" : "{actor} poisti sinulta moderaattorin oikeudet",
    "{actor} shared a file which is no longer available" : "{actor} jakoi kanssasi tiedoston, joka ei ole enää saatavilla",
    "You shared a file which is no longer available" : "Jaoit tiedoston, joka ei ole enää saatavilla",
    "%s (guest)" : "%s (vieras)",
    "Call with {user1} and {user2} (Duration {duration})" : "Puhelu käyttäjien {user1} ja {user2} kesken (Kesto {duration})",
    "Call with {user1}, {user2} and {user3} (Duration {duration})" : "Puhelu käyttäjien {user1}, {user2} ja {user3} kesken (Kesto {duration})",
    "Call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "Puhelu käyttäjien {user1}, {user2}, {user3} ja {user4} kesken (Kesto {duration})",
    "Call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "Puhelu käyttäjien {user1}, {user2}, {user3}, {user4} ja {user5} kesken (Kesto {duration})",
    "Password request: %s" : "Salasanapyyntö: %s",
    "_%n other guest_::_%n other guests_" : ["%n muu vieras","%n muuta vierasta"],
    ", " : ",",
    "%s invited you to a conversation." : "%s kutsui sinut keskusteluun.",
    "You were invited to a conversation." : "Sinut kutsuttiin keskusteluun.",
    "Conversation invitation" : "Keskustelukutsu",
    "Click the button below to join." : "Napsauta alla olevaa painiketta liittyäksesi.",
    "Join »%s«" : "Liity »%s«",
    "Join now" : "Liity nyt",
    "{user} sent you a private message" : "{user} lähetti sinulle yksityisviestin",
    "{user} sent a message in a conversation" : "{user} lähetti viestin keskusteluun",
    "A deleted user sent a message in a conversation" : "Poistettu käyttäjä lähetti viestin keskusteluun",
    "A guest sent a message in a conversation" : "Vieras lähetti viestin keskusteluun",
    "{user} mentioned you in a private conversation" : "{user} mainitsi sinut yksityiskeskustelussa",
    "{user} mentioned you in a conversation" : "{user} mainitsi sinut keskustelussa",
    "A deleted user mentioned you in a conversation" : "Poistettu käyttäjä mainitsi sinut keskustelussa",
    "A guest mentioned you in a conversation" : "Vieras mainitsi sinut keskustelussa",
    "%s invited you to a private conversation" : "%s kutsui sinut yksityiskeskusteluun",
    "{user} invited you to a private conversation" : "{user} kutsui sinut yksityiskeskusteluun",
    "%s invited you to a group conversation: %s" : "%s kutsui sinut ryhmäkeskusteluun: %s",
    "{user} invited you to a group conversation: {call}" : "{user} kutsui sinut ryhmäkeskusteluun: {call}",
    "%s invited you to a group conversation" : "%s kutsui sinut ryhmäkeskusteluun",
    "{user} invited you to a group conversation" : "{user} kutsui sinut ryhmäkeskusteluun",
    "{user} wants to talk with you" : "{user} haluaa puhua kanssasi",
    "A group call has started in {call}" : "Ryhmäpuhelu on alkanut puhelussa {call}",
    "A group call has started" : "Ryhmäpuhelu on alkanut",
    "Invalid date, date format must be YYYY-MM-DD" : "Virheellinen päiväys, päiväyksen muoto tulee olla YYYY-MM-DD",
    "Conversation not found" : "Keskustelua ei löydy",
    "Path is already shared with this room" : "Polku on jo jaettu tämän huoneen kesken",
    "Video & audio-conferencing using WebRTC" : "Video- ja äänipuheluita WebRTC:tä käyttäen",
    "This call is password-protected" : "Tämä puhelu on salasanasuojattu",
    "The password is wrong. Try again." : "Salasana on väärin. Yritä uudelleen.",
    "STUN servers" : "STUN-palvelimet",
    "TURN server" : "TURN-palvelin",
    "The TURN server is used to proxy the traffic from participants behind a firewall." : "TURN-palvelinta käytetään liikenteen välittämisessä palomuurin takana oleville osallistujille.",
    "%s Talk on your mobile devices" : "%s Keskustele mobiililaitteillasi",
    "Join conversations at any time, any where, on any device." : "Liity keskusteluun milloin tahansa, mistä tahansa, miltä laitteelta tahansa.",
    "Android app" : "Android-sovellus",
    "iOS app" : "iOS-sovellus",
    "(group)" : "(ryhmä)",
    "and you" : "ja sinä",
    "… %s" : "… %s",
    "%s …" : "%s …",
    "… %s …" : "… %s …",
    "%s mentioned you in a private conversation" : "%s mainitsi sinut yksityskeskustelussa",
    "%s mentioned you in a group conversation: %s" : "%s mainitsi sinut ryhmäkeskustelussa: %s",
    "{user} mentioned you in a group conversation: {call}" : "{user} mainitsi sinut ryhmäkeskustelussa: {call}",
    "%s mentioned you in a group conversation" : "%s mainitsi sinut ryhmäkeskustelussa",
    "{user} mentioned you in a group conversation" : "{user} mainitsi sinut ryhmäkeskustelussa",
    "You were mentioned in a group conversation by a deleted user: %s" : "Sinut mainittiin ryhmäkeskustelussa poistetun käyttäjän toimesta: %s",
    "You were mentioned in a group conversation by a deleted user" : "Sinut mainittiin ryhmäkeskustelussa poistetun käyttäjän toimesta",
    "A guest mentioned you in a group conversation: %s" : "Vieras mainitsi sinut ryhmäkeskustelussa: %s",
    "A guest mentioned you in a group conversation: {call}" : "Vieras mainitsi sinut ryhmäkeskustelussa: {call}",
    "A guest mentioned you in a group conversation" : "Vieras mainitsi sinut ryhmäkeskustelussa",
    "The TURN server settings are valid." : "TURN-palvelimen asetukset ovat kelvolliset.",
    "{email} requested the password to access a share" : "{email} pyysi salasanaa käyttääkseen jakoa"
},
"nplurals=2; plural=(n != 1);");
